SpecifierContext

Struct SpecifierContext 

pub struct SpecifierContext { /* private fields */ }
Context for expanding systemd specifiers

This contains the values that will be substituted when expanding specifiers in unit file values.

Implementations

Source

impl SpecifierContext

pub fn new() -> Self

Create a new empty specifier context

pub fn set(&mut self, specifier: &str, value: &str)

Set a specifier value

Example
let mut ctx = SpecifierContext::new();
ctx.set("i", "instance");
ctx.set("u", "user");
pub fn get(&self, specifier: &str) -> Option<&str>

Get a specifier value

pub fn with_unit_name(unit_name: &str) -> Self

Create a context with common system specifiers

This sets up commonly used specifiers with their values:

  • %n: Unit name (without type suffix)
  • %N: Full unit name
  • %p: Prefix (for template units)
  • %i: Instance (for template units)
Example
let ctx = SpecifierContext::with_unit_name("foo@bar.service");
assert_eq!(ctx.get("N"), Some("foo@bar.service"));
assert_eq!(ctx.get("n"), Some("foo@bar"));
assert_eq!(ctx.get("p"), Some("foo"));
assert_eq!(ctx.get("i"), Some("bar"));
pub fn expand(&self, input: &str) -> String

Expand specifiers in a string

This replaces all %X patterns with their corresponding values from the context. %% is replaced with a single %.

Example
let mut ctx = SpecifierContext::new();
ctx.set("i", "myinstance");
ctx.set("u", "myuser");

let result = ctx.expand("/var/lib/%i/data/%u");
assert_eq!(result, "/var/lib/myinstance/data/myuser");