Module systemd_metadata

Module systemd_metadata 

Systemd-specific metadata and domain knowledge Systemd-specific metadata and domain knowledge

This module contains information about systemd directives, their types, and how they should be merged in drop-in files.

Functions

is_accumulating_directive
Check if a directive is accumulating (values should be added rather than replaced)